#!/etc/opt/openit/perl -w
#
# Patch to add on new data types at end of acc_types
#
# Run in patch.cfg with
#
#   run:update_acc_types.pl:License.logfile.events:files/acc_types.add
#
# (data type is matched by regexp so the . will match space/^ in acc_types
#

use strict;

my $cfg = "/var/opt/openit/etc/acc_types";
my $old = "$cfg.old";
my $new = "$cfg.new";

# Only root can patch
if ( $< ne 0 ) {
    die "Error: Patching must be done as 'root'!\n";
}

open(IN, "$cfg") || die "Error: Unable to read old cfg '$cfg'!\n";

# Read in existing acc_types
my @lines = <IN>;
close(IN);

# Add denial reason. Skip update if it already exists.
my $ind = 0;
while($lines[$ind] !~ /License.logfile.events/ ) { # Find data type
    $ind++;
}
while($lines[$ind] !~ /Details/ ) { # Find previous last line
    $ind++;
}
if ( $lines[$ind] =~ /Details,/) { # If Details isn't last field we are done
    print "Update already done, skipping\n";
    exit 0;
}

$lines[$ind] =~ s/\)/,/; # Replace 
splice(@lines, $ind+1, 0, "   Forward^product)\n");

# Write new acc_types 
open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";
print OUT @lines;
close(OUT);

if( ! rename($cfg, $old)) {
    die "Error: Unable to previous config to '$old'!\n";
}

if( ! rename($new, $cfg)) {
    die "Error: Unable to rename new config to '$cfg'!\n";
}

exit 0;
