#!/etc/opt/openit/perl -w
#
# Patch to add on new data types at end of acc_types
#
# Run in patch.cfg with
#
#   run:update_acc_types.pl:License.logfile.events:files/acc_types.add
#
# (data type is matched by regexp so the . will match space/^ in acc_types
#

use strict;

my $cfg = "/var/opt/openit/etc/filtrator/license-events-flex-log.conf";
my $old = "$cfg.old";
my $new = "$cfg.new";

# Only root can patch
if ( $< ne 0 ) {
    die "Error: Patching must be done as 'root'!\n";
}

open(IN, "$cfg") || die "Error: Unable to read old cfg '$cfg'!\n";

# Read in existing acc_types
my @lines = <IN>;
close(IN);

# Add details to Summarize filter's compare line
my $ind = 0;
while($lines[$ind] !~ /compare/ ) { # Only one compare in this filter
    $ind++;
}
if ( $lines[$ind] =~ /,details/) {
    print "Update already done, skipping\n";
    exit 0;
}
$lines[$ind] =~ s/primetime/primetime,details/; # Add details cv

# Add details to Report filter's classification line
while($lines[$ind] !~ /classifications/ ) {
    $ind++;
}
$lines[$ind] =~ s/host/host:'0':details/;


# Write new file
open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";
print OUT @lines;
close(OUT);

if( ! rename($cfg, $old)) {
    die "Error: Unable to previous config to '$old'!\n";
}

if( ! rename($new, $cfg)) {
    die "Error: Unable to rename new config to '$cfg'!\n";
}

exit 0;
